@@ -16,7 +16,5 @@ ffGNN.gnn_GNN <- function(x, data)
     stopifnot(inherits(x, "gnn_GNN"))
     if(!is.matrix(data))
         data <- rbind(data)
-    if(ncol(data) != dim(x)[1])
-        stop("ncol(data) does not match dim(x)[1]")
     predict(x[["model"]], x = data)
 }
